==> owncloud-10.2.0.zip: owncloud/apps/federatedfilesharing/l10n/de_DE.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated-Sharing",
    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
    "Sharing %s failed, because this item is already shared with %s" : "Die Freigabe von %s ist fehlgeschlagen, da dieses Objekt schon mit %s geteilt wird",
    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated-Cloud-Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "File is already shared with %s" : "Datei wird bereits geteilt mit %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Die Freigabe von %s ist fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Sie haben \"/%3$s\" als Remotefreigabe von %1$s (als Teil von %2$s) erhalten",
    "You received \"/%3$s\" as a remote share from %1$s" : "Sie haben \"/%3$s\" als Remotefreigabe von %1$s erhalten",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID, siehe %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
    "Share it:" : "Zum Teilen:",
    "Add to your website" : "Zu Ihrer Website hinzufügen",
    "Share with me via ownCloud" : "Teilen Sie mit mir über ownCloud",
    "HTML Code:" : "HTML-Code:",
    "Add to your ownCloud" : "Zu Ihrer ownCloud hinzufügen"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/federatedfilesharing/l10n/de_DE.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated-Sharing",
    "Add to your ownCloud" : "Zu Ihrer ownCloud hinzufügen",
    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
    "Sharing %s failed, because this item is already shared with %s" : "Die Freigabe von %s ist fehlgeschlagen, da dieses Objekt schon mit %s geteilt wird",
    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated-Cloud-Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "File is already shared with %s" : "Datei wird bereits geteilt mit %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Die Freigabe von %s ist fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar.",
    "Federated Sharing failed: %s" : "Federated-Sharing fehlgeschlagen: %s",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" hat \"%3$s\" mit dir geteilt (im Auftrag von \"%2$s\")",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" hat \"%3$s\" mit Ihnen geteilt",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" hat Sie eingeladen \"%3$s\" anzusehen (im Auftrag von \"%2$s\")",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" hat Sie eingeladen \"%3$s\" anzusehen",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID, siehe %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Automatically accept remote shares from trusted servers" : "Freigaben von vertrauenswürdigen Servern automatisch annehmen",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
    "Share it:" : "Zum Teilen:",
    "Add to your website" : "Zu Ihrer Website hinzufügen",
    "Share with me via ownCloud" : "Teilen Sie mit mir über ownCloud",
    "HTML Code:" : "HTML-Code:",
    "Nothing to configure." : "Nichts zum Konfigurieren vorhanden."
},
"nplurals=2; plural=(n != 1);");
